Official Fintecture Bindings for Python
===================================

A Python library for Fintecture's API.


Setup
-----

You can install this package by using the pip tool and installing:

    $ pip install fintecture

Or:

    $ easy_install fintecture


Setting up a Fintecture Account
---------------------------

Sign up for Fintecture at https://console.fintecture.com/auth/signup.

Using the Fintecture API
--------------------

Documentation for the python bindings can be found alongside Fintecture's other bindings here:

- https://docs.fintecture.com/
- https://docs.fintecture.com/?lang=python

In the standard documentation (the first link), most of the reference pages will have examples in Fintecture's official bindings (including Python). Just click on the Python tab to get the relevant documentation.

In the full API reference for python (the second link), the right half of the page will provide example requests and responses for various API calls.
